<!-- PlazaLocationManage 广场地点管理 -->
<template>
    <div class="main-big">
        <div class="main-table">
            <div class="main-search">
                <el-form ref="form" :model="parameter" label-width="auto">
                    <div style="display: flex">
                        <el-input
                            style="width: 30%;"
                            v-model="querys[0].value"
                            clearable
                            placeholder="请输入广场名称"
                        ></el-input>
                        <el-cascader
                        style="margin:0 0 0 5px"
                            ref="cascaders"
                            v-model="areaList"
                            :props="{
                                label: 'name',
                                value: 'code',
                                checkStrictly: true,
                            }"
                            @change="handleChange"
                            :options="options"
                            placeholder="请输入行政区划"
                        ></el-cascader>
                        <el-button
                            icon="el-icon-search"
                            type="primary"
                            class="btn btn-plus"
                            style="margin-left: 10px"
                            @click="getData(1)"
                        >
                            搜索
                        </el-button>
                        <el-button
                            icon="el-icon-plus"
                            type="primary"
                            class="btn btn-plus"
                            @click="handleAdd"
                            v-methodauth="'PlazaLocationManage_add'"
                        >
                            新增
                        </el-button>
                    </div>
                </el-form>
            </div>
            <div class="table-wrapper">
                <el-table
                    stripe
                    size="mini"
                    v-loading="tableLoading"
                    ref="tableData"
                    :data="tableData"
                    height="100%"
                    :style="{width: '100%'}"
                    highlight-current-row
                    @current-change="handleCurrentRow"
                    :default-sort="{prop: 'status', order: 'ascending'}"
                >
                    <el-table-column
                        prop="squareLocationName"
                        show-overflow-tooltip
                        label="广场名称"
                        align="center"
                    >
                    </el-table-column>
                    <el-table-column
                        prop="areaFullName"
                        show-overflow-tooltip
                        label="行政区划"
                        min-width="90"
                        align="center"
                    >
                        <template v-slot="{row}">
                            {{
                                row.areaFullName.split('/')[
                                    row.areaFullName.split('/').length - 1
                                ]
                            }}
                        </template>
                    </el-table-column>
                    <!-- <el-table-column
                        prop="noiseTypeName"
                        show-overflow-tooltip
                        label="噪音分类"
                        align="center"
                    >
                    </el-table-column>
                    <el-table-column
                        prop="noiseLevelName"
                        show-overflow-tooltip
                        label="噪音级别"
                        align="center"
                    >
                    </el-table-column> -->
                    <el-table-column
                        prop="detailAddress"
                        show-overflow-tooltip
                        label="详细地址"
                        align="center"
                    >
                    </el-table-column>
                    <el-table-column
                        show-overflow-tooltip
                        align="center"
                        min-width="80"
                        label="操作"
                    >
                        <template v-slot="{row}">
                            <el-dropdown
                                @command="
                                    (command) => {
                                        handleCommand(command, row)
                                    }
                                "
                            >
                                <span class="el-dropdown-link">
                                    <i
                                        class="el-icon-more"
                                        style="font-weight: bold"
                                    ></i>
                                </span>
                                <el-dropdown-menu slot="dropdown">
                                    <el-dropdown-item
                                        command="edit"
                                        icon="el-icon-edit-outline"
                                        style="color: #409eff"
                                        v-methodauth="
                                            'PlazaLocationManage_edit'
                                        "
                                        >编辑</el-dropdown-item
                                    >
                                    <el-dropdown-item
                                        command="delete"
                                        icon="el-icon-delete"
                                        style="color: #f56c6c"
                                        v-methodauth="
                                            'PlazaLocationManage_delete'
                                        "
                                        >删除</el-dropdown-item
                                    >
                                </el-dropdown-menu>
                            </el-dropdown>
                        </template>
                    </el-table-column>
                </el-table>
            </div>
            <pagination
                ref="paginationPanel"
                style="margin-top: 10px"
                :pageResult="pageResult"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>
        <div class="main-map" id="map"></div>
        <PlazaLocationDialog
            ref="formDialog"
            @getData="getData"
        ></PlazaLocationDialog>
    </div>
</template>
<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import pilotprojects from '@/api/basicConfiguration/PlazaLocation'
import PlazaLocationDialog from './components/PlazaLocationDialog'
import utils from '@/utils.js'
import MapInit from '@/components/MapInit.js'

import 'leaflet/dist/leaflet.css'
import 'leaflet.markercluster/dist/MarkerCluster.css'
import 'leaflet.markercluster/dist/MarkerCluster.Default.css'
import L from 'leaflet'
import 'leaflet.markercluster'
import wanzhou from '@/assets/js/wanzhougeojson.js'
import Team from '@/api/basicConfiguration/Team'
export default {
    name: 'NoiseLevelManage',
    components: {
        pagination,
        PlazaLocationDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            tableMaxHeight: 400,
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'squareLocationName',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'l.area_full_code_',
                    relation: 'AND',
                    value: '',
                },
            ],
            reqData: {
                querys: [],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
            },
            tableLoading: false,
            deleteIds: '',
            parameter: {
                size: 20,
                page: 1,
            },
            map: null,
            baseMapOverlay: null,
            zoom: 9,
            Clusterer: null,
            currentRow: null,
            areaList: [],
            options: [],
        }
    },

    created() {},
    mounted() {
        this.$nextTick(() => {
            this.roadMap()
            this.areaList = this.$store.state.user.currentUserDetail.org[0]
                .orgAddvcdFull
                ? this.$store.state.user.currentUserDetail.org[0].orgAddvcdFull
                      .split('/')
                      .splice(1)
                : []
            this.querys[1].value =
                this.$store.state.user.currentUserDetail.org[0].orgAddvcdFull
            this.getTownTree()
            this.getData()
        })
    },
    methods: {
        roadMap() {
            this.map = new L.Map('map', {
                crs: L.CRS.EPSG4326,
                scrollWheelZoom: true,
                attributionControl: false,
                zoomControl: false,
                center: [30.707807, 108.390246],
                zoom: this.zoom,
                // layers: [lay, lay2],
            })
            const imageURL =
                window.context.frontMap +
                '/vec_c/wmts?SERVICE=WMTS&REQUEST=GetTile&VERSION=1.0.0&LAYER=vec&STYLE=default&TILEMATRIXSET=c&FORMAT=tiles' +
                '&TILEMATRIX={z}&TILEROW={y}&TILECOL={x}' +
                '&tk=bff554ec2d59ec30f9f7debffd440624'

            //   卫星底图
            const imageURL2 =
                window.context.frontMap +
                '/cva_c/wmts?layer=cva&style=default&tilematrixset=c&Service=WMTS&Request=GetTile&Version=1.0.0&Format=tiles' +
                '&TileMatrix={z}&TileCol={x}&TileRow={y}' +
                '&tk=f6df78cf1738e5623e2291f608e7040e'
            //	正常线路地图
            // const imageURLT = "http://t0.tianditu.gov.cn/cia_w/wmts?" +
            // 	"SERVICE=WMTS&REQUEST=GetTile&VERSION=1.0.0&LAYER=cia&STYLE=default&TILEMATRIXSET=w&FORMAT=tiles" +
            // 	"&TILEMATRIX={z}&TILEROW={y}&TILECOL={x}" +
            // 	"&tk=f6df78cf1738e5623e2291f608e7040e";
            const lay = new L.TileLayer(imageURL, {
                zoomOffset: 1,
                zIndex: 1,
            })

            const lay2 = new L.TileLayer(imageURL2, {
                zoomOffset: 1,
                zIndex: 2,
            })
            const config = {
                layers: [lay, lay2],
            }

            lay2.addTo(this.map)
            lay.addTo(this.map)
            this.initWZ()
        },
        initWZ() {
            let countries = []
            countries = wanzhou.features
            var myStyle = {
                color: '#1a8cff', //'#d2e0e1',
                weight: 3,
                opacity: 1,
                fillColor: 'transparent', //'transparent',
                fillOpacity: 0,
            }
            this.baseMapOverlay = new L.geoJSON(countries, {
                style: myStyle,
            })
            this.map.addLayer(this.baseMapOverlay)
            this.baseMapOverlay.bringToBack()
        },
        //获取数据
        getData(page) {
            if (page) {
                this.reqData.pageBean.page = page
            }
            this.tableLoading = true
            this.reqData.querys = []
            if (this.querys[0].value) {
                this.reqData.querys.push(this.querys[0])
            }
             if (this.querys[1].value) {
                this.reqData.querys.push(this.querys[1])
            }
            pilotprojects.dataQuery(this.reqData, (res) => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
                this.tableData.length
                    ? this.handlePoint(this.tableData)
                    : this.clearPoints()
            })
        },
        handleCurrentRow(val) {
            this.currentRow = val
            this.currentRow && this.handlePoint([this.currentRow])
        },
        drawPoints(data) {
            //图标
            var icon = new L.icon({
                iconUrl: require('@/assets/img/icon-2.png'), //请求图标图片的URL
                iconSize: new L.point(25, 25), //图标可视区域的大小。
                iconAnchor: new L.point(8, 25),
            })
            this.MarkerGroup = [] //存放节点

            data.forEach((item) => {
                // let latlng = new L.LatLng(item.lttd, item.lgtd)
                var position = new L.LatLng(
                    Number(item.lttd),
                    Number(item.lgtd)
                )
                let marker = new L.Marker(position, {
                    icon: icon,
                    autoPan: true,
                })
                marker.bindPopup(`${item.squareLocationName}`).openPopup()
                this.Clusterer.addLayer(marker)
            })
            this.map.addLayer(this.Clusterer)
        },
        handlePoint(data) {
            this.clearPoints()
            this.markerClusterer()
            this.drawPoints(data)
        },
        markerClusterer(type) {
            // 初始化点聚合
            this.Clusterer = new L.markerClusterGroup({
                spiderfyOnMaxZoom: false,
                showCoverageOnHover: false,
                zoomToBoundsOnClick: true,
            })

            // 聚合点点击事件，点击展开点
            this.Clusterer.on('clusterclick', function (e) {
                e.layer.zoomToBounds()
            })
        },
        clearPoints(type) {
            this.Clusterer &&
                this.Clusterer.clearLayers &&
                this.Clusterer.clearLayers()
        },
        handleSizeChange(val) {
            this.reqData.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.reqData.pageBean.page = val
            this.getData()
        },
        handleCommand(command, row) {
            console.log(row, command)
            switch (command) {
                case 'edit':
                    this.$refs.formDialog.edit(row.id)

                    break
                case 'delete':
                    this.$confirm('确认删除吗？', this.$t('common.tips'), {
                        confirmButtonText: this.$t('common.confirm'),
                        cancelButtonText: this.$t('common.cancel'),
                        type: 'success',
                    }).then(() => {
                        this.markLoading = true
                        pilotprojects.remove(row.id, (res) => {
                            if (res.state) {
                                this.$message.success('删除成功')
                            }
                            this.markLoading = false
                            this.getData()
                        })
                    })
                    break

                default:
                    break
            }
        },
        // 编辑
        handleEdit(item) {
            this.$refs.formDialog.edit(item.id)
        },
        // 删除
        handleDelete(item) {
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'success',
            }).then(() => {
                this.markLoading = true
                pilotprojects.remove(item.id, (res) => {
                    if (res.state) {
                        this.$message.success('删除成功')
                    }
                    this.markLoading = false
                    this.getData()
                })
            })
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map((item) => item.id)
            this.deleteIds = arr.join(',')
            console.log(this.deleteIds)
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        handleChange(val) {
            this.querys[1].value = val[val.length - 1]
        },
        getTownTree() {
            Team.townTree({}, (res) => {
                if (res.state) {
                    this.options = res.value
                }
            })
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';
@import '~@/assets/css/common.scss';

.main-big {
    display: flex;
    width: 100%;
    height: 100%;

    .main-table {
        width: 38%;
        padding: 20px;
        box-sizing: border-box;
        border-radius: 20px;
        background-color: #ffffff;

        .main-search {
            margin-bottom: 20px;
        }
    }

    .main-map {
        width: 62%;
    }
}
</style>
